==> haskell-dns-2.0.2-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dns
version: 2.0.2
id: dns-2.0.2-HIn9lo74iAS6i7gjpFxPDK
key: dns-2.0.2-HIn9lo74iAS6i7gjpFxPDK
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.DNS Network.DNS.Lookup Network.DNS.Resolver
    Network.DNS.Utils Network.DNS.Types Network.DNS.Encode
    Network.DNS.Decode
hidden-modules: Network.DNS.Internal Network.DNS.StateBinary
abi: 6bb22fbf827286bd7d964162030e9575
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/dns-2.0.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/dns-2.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/dns-2.0.2
hs-libraries: HSdns-2.0.2-HIn9lo74iAS6i7gjpFxPDK
depends:
    attoparsec-0.13.0.2-9hiBNMll4LoGE6dCvh31fM base-4.9.0.0
    binary-0.8.3.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 conduit-1.2.6.6-DP6wmtnPfNiE72BJILsUMh
    conduit-extra-1.1.13.1-IbX5PRJ7heVEqTz6YCjQ7U containers-0.5.7.1
    iproute-1.7.0-3gBtqYPiXNzAiDCAky7oBX
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    network-2.6.2.1-Li0aefQhyJzUSpQ0fLiXL
    random-1.1-54KmMHXjttlERYcr1mvsAe
    resourcet-1.1.7.4-5MzcrbA8GQD6CRuZwV7nMM
haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html: /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dns-2.0.2-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dns
version: 2.0.2
id: dns-2.0.2-4qbwIc1X3TpE6nLy9co8AG
key: dns-2.0.2-4qbwIc1X3TpE6nLy9co8AG
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.DNS Network.DNS.Lookup Network.DNS.Resolver
    Network.DNS.Utils Network.DNS.Types Network.DNS.Encode
    Network.DNS.Decode
hidden-modules: Network.DNS.Internal Network.DNS.StateBinary
abi: 42c0cd641ea59e9f29d64c008320547d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/dns-2.0.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/dns-2.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/dns-2.0.2
hs-libraries: HSdns-2.0.2-4qbwIc1X3TpE6nLy9co8AG
depends:
    attoparsec-0.13.0.2-HXBOMFQRhhb7ZddTjkE24r base-4.9.0.0
    binary-0.8.3.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 conduit-1.2.6.6-DP6wmtnPfNiE72BJILsUMh
    conduit-extra-1.1.13.1-l1HsAoHEKPFqe5VO2k2qY containers-0.5.7.1
    iproute-1.7.0-3gBtqYPiXNzAiDCAky7oBX
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    network-2.6.2.1-Li0aefQhyJzUSpQ0fLiXL
    random-1.1-54KmMHXjttlERYcr1mvsAe
    resourcet-1.1.7.4-5MzcrbA8GQD6CRuZwV7nMM
haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html: /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
